package com.mycompany.commerce.catalog.facade.client;

/*
 *-------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * WebSphere Commerce
 *
 * (c) Copyright International Business Machines Corporation.
 *     2006, 2007
 *     All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the US Copyright Office.
 *-------------------------- -----------------------------------------
 */


import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import junit.framework.TestCase;

import com.ibm.commerce.catalog.facade.client.CatalogEntryException;
import com.ibm.commerce.catalog.facade.client.CatalogEntryFacadeClient;
import com.ibm.commerce.catalog.facade.datatypes.CatalogEntryType;
import com.ibm.commerce.catalog.facade.datatypes.CatalogFactory;
import com.ibm.commerce.catalog.facade.datatypes.RespondCatalogEntryDataAreaType;
import com.ibm.commerce.catalog.facade.datatypes.ShowCatalogEntryDataAreaType;
import com.ibm.commerce.foundation.client.util.oagis.SelectionCriteriaHelper;
import com.ibm.commerce.foundation.common.datatypes.CommerceFoundationFactory;
import com.ibm.commerce.foundation.common.datatypes.ContextDataType;
import com.ibm.commerce.foundation.common.datatypes.UserDataType;
import com.ibm.commerce.oagis9.datatypes.ExpressionType;
import com.ibm.commerce.oagis9.datatypes.GetType;

/**
 * This class represents a set of test cases for testing the
 * SOATestStore facade client.
 */
public class CatalogExtensionFacadeClientTest extends junit.framework.TestCase {
	
	/**
	 * TODO set your WebSphere Commerce administrator user id.
	 */
	private static final String USER_ID = "wcsadmin";
	/**
	 * TODO set the password for your WebSphere Commerce user id.
	 */
	private static final String PASSWORD = "wcs1admin";
	
	/**
	 * The catalog id for these unit tests.
	 */
	private static final String CATALOG_ID = "10101";

	/**
	 * The store id for these unit tests.
	 */
	private static final String STORE_ID = "10101";
	
	private CatalogEntryFacadeClient iCatalogEntryClient = null;
			
	/**
	 * Create an instance of the CatalogExtension Facade Client test case.
	 * @param method The test method to execute.
	 */
	public CatalogExtensionFacadeClientTest(String method) {
		super(method);
	}

	/**
	 * Set up any additional information required in order to run any test method.
	 * As part of the setup, the client library will be instantiated for the test case. 
	 * @exception A problem with the setup process.
	 * @see TestCase#setUp()
	 */
	protected void setUp() throws Exception {
		super.setUp();
		
		javax.security.auth.callback.CallbackHandler callbackHandler = new com.ibm.commerce.foundation.client.samples.security.auth.callback.SampleCallbackHandlerImpl(USER_ID, PASSWORD);
		com.ibm.commerce.foundation.common.datatypes.BusinessContextType businessContext = com.ibm.commerce.foundation.common.datatypes.CommerceFoundationFactory.eINSTANCE.createBusinessContextType();
		
		// Setup the language Id in the context.  The language Id is used to select the appropriate store description.
		ContextDataType languageIdContext = CommerceFoundationFactory.eINSTANCE.createContextDataType();
		languageIdContext.setName("languageId");
		languageIdContext.setValue("-1");
		
		// Setup the catalog Id in the context.
		ContextDataType catalogIdContext = CommerceFoundationFactory.eINSTANCE.createContextDataType();
		catalogIdContext.setName("catalogId");
		catalogIdContext.setValue(CATALOG_ID);
		
		// Setup the store Id in the context.
		ContextDataType storeIdContext = CommerceFoundationFactory.eINSTANCE.createContextDataType();
		storeIdContext.setName("storeId");
		storeIdContext.setValue(STORE_ID);
		
		businessContext.getContextData().add(languageIdContext);
		businessContext.getContextData().add(catalogIdContext);
		businessContext.getContextData().add(storeIdContext);
		
		// Create the CatalogEntry client.  This client is used to send requests and receive responses from the server.
		iCatalogEntryClient = new CatalogEntryFacadeClient(businessContext, callbackHandler);
	}
	
	/**
	 * Remove any data or setting related to running any test method.
	 * @exception A problem with the tear down process.
	 * @see TestCase#tearDown() 
	 */
	protected void tearDown() throws Exception {
		super.tearDown();
	}

	/**
	 * The access profile used in Get requests.
	 */
	public String getCustomizationAccessProfile = "MyCompany_All";
	
	/** 
	 * The XPath used to find catalog entries.
	 */
	public String findByCatalogEntryIdXPath = "/CatalogEntry[CatalogEntryIdentifier[(UniqueID={0})]]";
	/**
	 * The catentry to find.
	 */
	public String catEntryId = "10101";
    public String[] catEntryIdArray = {catEntryId};
    
    /**
     * The change action to perform.
     */
    public String[] changeActions = {"change"};
    
    /**
     * The change expression.
     */
    public String[] changeExpressions = {"/CatalogEntry[1]"};
    
       	     
    /**
     * 
     *
     */
	public void testCatalogEntryCustomization() {
		
		// Create the get expression using the access profile, XPath, and catentry to find.
		SelectionCriteriaHelper selectionCriteriaHelper = new SelectionCriteriaHelper(MessageFormat.format(findByCatalogEntryIdXPath, catEntryIdArray));
		selectionCriteriaHelper.addAccessProfile(getCustomizationAccessProfile);
		ExpressionType getExpression = selectionCriteriaHelper.getSelectionCriteriaExpression();
		
		// Create the get verb using the get expression.
		GetType get = CatalogEntryFacadeClient.createGetVerb(getExpression);
		
				
		try {
			// Perform the get request.
			ShowCatalogEntryDataAreaType showCatalogEntryDataArea = iCatalogEntryClient.getCatalogEntry(get);
		
			// Validate the show response.
			List showCatalogEntries = showCatalogEntryDataArea.getCatalogEntry();
			CatalogEntryType aCatalogEntry = null;
					
			Iterator showCatalogEntriesIter = showCatalogEntries.iterator();
			while (showCatalogEntriesIter.hasNext()) {
				aCatalogEntry = (CatalogEntryType) showCatalogEntriesIter.next();
				assertEquals("30", aCatalogEntry.getUserData().getUserDataField().get("warterm"));
				assertEquals("LIMITED", aCatalogEntry.getUserData().getUserDataField().get("wartype"));
			}
			
			// Update the user data.
			UserDataType userData = aCatalogEntry.getUserData();
			Map userDataMap = userData.getUserDataField();
			userDataMap.put("warterm", "365");
			
			// Create a catalog entry noun containing the updated user data.
			CatalogEntryType catalogEntryToChange = CatalogFactory.eINSTANCE.createCatalogEntryType();
			catalogEntryToChange.setCatalogEntryIdentifier(aCatalogEntry.getCatalogEntryIdentifier());
			catalogEntryToChange.setUserData(userData);
			CatalogEntryType[] changeCatalogEntries = {catalogEntryToChange};
			
			
			// Perform the change request.
			RespondCatalogEntryDataAreaType respondCatalogEntryDataArea = null;
		
			respondCatalogEntryDataArea = iCatalogEntryClient.changeCatalogEntry(changeActions, changeCatalogEntries, changeExpressions);
		

			// Validate the respond response.
			List respondCatalogEntries = respondCatalogEntryDataArea.getCatalogEntry();
			Iterator respondCatalogEntriesIter = respondCatalogEntries.iterator();
			while (respondCatalogEntriesIter.hasNext()) {
				aCatalogEntry = (CatalogEntryType) respondCatalogEntriesIter.next();
				assertEquals("365", aCatalogEntry.getUserData().getUserDataField().get("warterm"));
			}
		} catch (CatalogEntryException e) {
			e.printStackTrace();
		}
	}
	
	

}